@@ -1,8 +1,7 @@
-
-from .depends import create_ratelimit_depends
-from .error_handler import LimiterErrorHandler
+from .error_handler import ErrorHandler
+from .frontend import create_ratelimit_decorator, create_ratelimit_depends, create_ratelimit_middleware
+from .limit_config import LimitConfig
 from .limiter_engine import LimiterEngine
-from .decorator import create_ratelimit_decorator
 
 
 class Limiter:
@@ -10,7 +9,7 @@ class Limiter:
     def __init__(
             self,
             engine: LimiterEngine,
-            error_handler: LimiterErrorHandler
+            error_handler: ErrorHandler
     ):
         self.engine = engine
         self.error_handler = error_handler
@@ -22,3 +21,6 @@ class Limiter:
     @property
     def depends(self):
         return create_ratelimit_depends(self.engine, self.error_handler)
+
+    def middleware(self, config: LimitConfig):
+        return create_ratelimit_middleware(self.engine, self.error_handler, config)
